from ejtraderMT import Metatrader
from threading import Thread




api = Metatrader()

symbols = ["EURUSD","GBPUSD","AUDUSD"]
timeframe = "TICK"


# Live data stream subscribe
api.live(symbols,timeframe)




def price():
    connect = api.livePrice
    while True:
        price = connect.recv_json()
        print(price)


def event():
    connect = api.liveEvent
    while True:
        event = connect.recv_json()
        print(event)




t = Thread(target=price, daemon=True)
t.start()

t = Thread(target=event, daemon=True)
t.start()




while True:
    pass


from ejtraderMT import Metatrader


api = Metatrader()

symbol = "EURUSD"
symbols = [symbol,"GBPUSD","AUDUSD"]
timeframe = "M1"
fromDate = "24/02/2021"
toDate = "26/02/2021"

data = api.historyDataFrame(symbol,timeframe,fromDate,toDate,True)



print(data)




symbols = ['EURUSD',
           'GBPUSD',
           'EURJPY']
        #    'USDJPY',
        #    'AUDUSD',
        #    'USDCHF',
        #    'GBPJPY',
        #    'USDCAD',
        #    'EURGBP',
        #    'EURCHF',
        #    'AUDJPY']
        #    'NZDUSD',
        #    'CHFJPY',
        #    'EURAUD',
        #    'CADJPY',
        #    'GBPAUD',
        #    'EURCAD',
        #    'AUDCAD',
        #    'GBPCAD',
        #    'AUDNZD',
        #    'NZDJPY',
        #    'USDNOK',
        #    'AUDCHF',
        #    'USDMXN',
        #    'GBPNZD',
        #    'EURNZD',
        #    'CADCHF',
        #    'USDSGD',
        #    'USDSEK',
        #    'NZDCAD',
        #    'EURSEK',
        #    'GBPSGD',
        #    'EURNOK',
        #    'EURHUF',
        #    'USDPLN',
        #    'USDDKK',
        #    'GBPNOK',
        #    'NZDCHF',
        #    'GBPCHF',
        #    'USDTRY',
        #    'EURTRY',
        #    'EURZAR',
        #    'SGDJPY',
        #    'USDHKD',
        #    'USDZAR',
        #    'EURMXN',
        #    'EURPLN',
        #    'NZDSGD',
        #    'USDHUF',
        #    'EURCZK',
        #    'USDCZK',
        #    'EURDKK',
        #    'USDCNH',
        #    'GBPSEK']



import persistqueue
import pandas as pd
import time

symbol = "EURUSD"

q = persistqueue.SQLiteQueue(f'data/{symbol}', auto_commit=False)

start_time = time.time()
data = q.get()
print(("--- %s seconds ---" % (time.time() - start_time)))   
    




data = pd.DataFrame(data, columns=['date','open', 'high', 'low','close','volume','spread'])
data =  data.set_index(['date'])
print(data)


import persistqueue
from ejtraderMT import Metatrader
from datetime import date, timedelta
import time
from symbols import symbols
import pandas as pd
import os

start_time = time.time()
api = Metatrader()


active = symbols
timeframe = "M1"

# q = persistqueue.SQLiteQueue(f'data/{symbol}', auto_commit=True)
try:
    os.makedirs('data')
except OSError:
    pass


start_date = date(2019, 1, 1)
end_date = date(2021, 1, 1)
delta = timedelta(days=30)
delta2 = timedelta(days=30)

while start_date <= end_date:
    fromDate = start_date.strftime("%d/%m/%Y")
    toDate = start_date
    toDate +=  delta2
    toDate = toDate.strftime("%d/%m/%Y")
    for symbol in active:
        
        data = api.historyDataFrame(symbol,timeframe,fromDate,toDate)
        data.to_csv (f'data/{symbol}.csv', index = True, header=True)
        print(f'writing to Database... from: {fromDate} to {toDate} symbol: {symbol}')
        start_date += delta
         

for symbol in active:
    q = persistqueue.SQLiteQueue(f'data/{symbol}', auto_commit=True)
    df = pd.read_csv(f'data/{symbol}.csv')
    q.put(df)
    # Get directory name
    MODELFILE = f'data/{symbol}.csv'
    try:
        os.remove(MODELFILE)
    except OSError:
        pass

print(("--- %s seconds ---" % (time.time() - start_time)))    



        














from ejtraderMT import Metatrader


api = Metatrader()

symbol = "EURUSD"
timeframe = "M1"
fromDate = "01/01/2021"
toDate = "01/02/2021"

data = api.history(symbol,timeframe,fromDate,toDate)


print(data)

